@@ -7,23 +7,20 @@ mod common;
 use std::{fs, path::PathBuf};
 use test::Bencher;
 
-use once_cell::sync::OnceCell;
+use once_cell::sync::Lazy;
 
 use fern::Dispatch;
 use log::info;
 
-fn logs_path() -> &'static PathBuf {
-    static LOGS_PATH: OnceCell<PathBuf> = OnceCell::new();
-    LOGS_PATH.get_or_init(|| {
-        let path = common::bench_logs_path().join("fern");
-        fs::create_dir_all(&path).unwrap();
-        path
-    })
-}
+static LOGS_PATH: Lazy<PathBuf> = Lazy::new(|| {
+    let path = common::BENCH_LOGS_PATH.join("fern");
+    fs::create_dir_all(&path).unwrap();
+    path
+});
 
 #[bench]
 fn bench_file(bencher: &mut Bencher) {
-    let path = logs_path().join("file.log");
+    let path = LOGS_PATH.join("file.log");
 
     Dispatch::new()
         .format(|out, message, record| {
