@@ -7,7 +7,7 @@ mod common;
 use std::{fs, path::PathBuf, sync::Mutex};
 use test::Bencher;
 
-use once_cell::sync::OnceCell;
+use once_cell::sync::Lazy;
 
 use flexi_logger::{
     writers::FileLogWriter, Age, Cleanup, Criterion, DeferredNow, FileSpec, LogSpecification,
@@ -15,28 +15,22 @@ use flexi_logger::{
 };
 use log::{info, Record};
 
-fn logs_path() -> &'static PathBuf {
-    static LOGS_PATH: OnceCell<PathBuf> = OnceCell::new();
-    LOGS_PATH.get_or_init(|| {
-        let path = common::bench_logs_path().join("flexi_logger");
-        fs::create_dir_all(&path).unwrap();
-        path
-    })
-}
+static LOGS_PATH: Lazy<PathBuf> = Lazy::new(|| {
+    let path = common::BENCH_LOGS_PATH.join("flexi_logger");
+    fs::create_dir_all(&path).unwrap();
+    path
+});
 
-fn handle() -> &'static Mutex<LoggerHandle> {
-    static HANDLE: OnceCell<Mutex<LoggerHandle>> = OnceCell::new();
-    HANDLE.get_or_init(|| {
-        Mutex::new(
-            Logger::with(LogSpecification::off())
-                .log_to_file(FileSpec::try_from(logs_path().join("empty.log")).unwrap())
-                .write_mode(WriteMode::BufferDontFlush)
-                .format(formatter)
-                .start()
-                .unwrap(),
-        )
-    })
-}
+static HANDLE: Lazy<Mutex<LoggerHandle>> = Lazy::new(|| {
+    Mutex::new(
+        Logger::with(LogSpecification::off())
+            .log_to_file(FileSpec::try_from(LOGS_PATH.join("empty.log")).unwrap())
+            .write_mode(WriteMode::BufferDontFlush)
+            .format(formatter)
+            .start()
+            .unwrap(),
+    )
+});
 
 pub fn formatter(
     w: &mut dyn std::io::Write,
@@ -54,13 +48,13 @@ pub fn formatter(
 
 #[bench]
 fn bench_file(bencher: &mut Bencher) {
-    let path = logs_path().join("file.log");
+    let path = LOGS_PATH.join("file.log");
 
     let writer_builder = FileLogWriter::builder(FileSpec::try_from(path).unwrap())
         .write_mode(WriteMode::BufferDontFlush)
         .format(formatter);
 
-    let mut handle = handle().lock().unwrap();
+    let mut handle = HANDLE.lock().unwrap();
     handle.set_new_spec(LogSpecification::info());
     handle.reset_flw(&writer_builder).unwrap();
 
@@ -69,7 +63,7 @@ fn bench_file(bencher: &mut Bencher) {
 
 #[bench]
 fn bench_rotating_file_size(bencher: &mut Bencher) {
-    let path = logs_path().join("rotating_file_size.log");
+    let path = LOGS_PATH.join("rotating_file_size.log");
 
     let writer_builder = FileLogWriter::builder(FileSpec::try_from(path).unwrap())
         .write_mode(WriteMode::BufferDontFlush)
@@ -80,7 +74,7 @@ fn bench_rotating_file_size(bencher: &mut Bencher) {
             Cleanup::KeepLogFiles(common::ROTATING_FILES),
         );
 
-    let mut handle = handle().lock().unwrap();
+    let mut handle = HANDLE.lock().unwrap();
     handle.set_new_spec(LogSpecification::info());
     handle.reset_flw(&writer_builder).unwrap();
 
@@ -89,7 +83,7 @@ fn bench_rotating_file_size(bencher: &mut Bencher) {
 
 #[bench]
 fn bench_rotating_daily(bencher: &mut Bencher) {
-    let path = logs_path().join("rotating_daily.log");
+    let path = LOGS_PATH.join("rotating_daily.log");
 
     let writer_builder = FileLogWriter::builder(FileSpec::try_from(path).unwrap())
         .write_mode(WriteMode::BufferDontFlush)
@@ -100,7 +94,7 @@ fn bench_rotating_daily(bencher: &mut Bencher) {
             Cleanup::KeepLogFiles(common::ROTATING_FILES),
         );
 
-    let mut handle = handle().lock().unwrap();
+    let mut handle = HANDLE.lock().unwrap();
     handle.set_new_spec(LogSpecification::info());
     handle.reset_flw(&writer_builder).unwrap();
 
@@ -109,10 +103,7 @@ fn bench_rotating_daily(bencher: &mut Bencher) {
 
 #[bench]
 fn bench_level_off(bencher: &mut Bencher) {
-    handle()
-        .lock()
-        .unwrap()
-        .set_new_spec(LogSpecification::off());
+    HANDLE.lock().unwrap().set_new_spec(LogSpecification::off());
 
     bencher.iter(|| info!(bench_log_message!()))
 }
