@@ -7,22 +7,19 @@ mod common;
 use std::{fs, path::PathBuf, sync::Arc};
 use test::Bencher;
 
-use once_cell::sync::OnceCell;
+use once_cell::sync::Lazy;
 
 use spdlog::{prelude::*, sink::*, LevelFilter, Logger};
 
-fn logs_path() -> &'static PathBuf {
-    static LOGS_PATH: OnceCell<PathBuf> = OnceCell::new();
-    LOGS_PATH.get_or_init(|| {
-        let path = common::bench_logs_path().join("spdlog_rs");
-        fs::create_dir_all(&path).unwrap();
-        path
-    })
-}
+static LOGS_PATH: Lazy<PathBuf> = Lazy::new(|| {
+    let path = common::BENCH_LOGS_PATH.join("spdlog_rs");
+    fs::create_dir_all(&path).unwrap();
+    path
+});
 
 #[bench]
 fn bench_file(bencher: &mut Bencher) {
-    let path = logs_path().join("file.log");
+    let path = LOGS_PATH.join("file.log");
 
     let sink = Arc::new(FileSink::new(path, true).unwrap());
     let logger = Logger::builder().sink(sink).build();
@@ -32,7 +29,7 @@ fn bench_file(bencher: &mut Bencher) {
 
 #[bench]
 fn bench_rotating_file_size(bencher: &mut Bencher) {
-    let path = logs_path().join("rotating_file_size.log");
+    let path = LOGS_PATH.join("rotating_file_size.log");
 
     let sink = Arc::new(
         RotatingFileSink::new(
@@ -50,7 +47,7 @@ fn bench_rotating_file_size(bencher: &mut Bencher) {
 
 #[bench]
 fn bench_rotating_daily(bencher: &mut Bencher) {
-    let path = logs_path().join("rotating_daily.log");
+    let path = LOGS_PATH.join("rotating_daily.log");
 
     let sink = Arc::new(
         RotatingFileSink::new(
