@@ -79,12 +79,14 @@
 //! release and debug builds. The features are:
 //!
 //!  - `level-off`
+//!  - `level-critical`
 //!  - `level-error`
 //!  - `level-warn`
 //!  - `level-info`
 //!  - `level-debug`
 //!  - `level-trace`
 //!  - `release-level-off`
+//!  - `release-level-critical`
 //!  - `release-level-error`
 //!  - `release-level-warn`
 //!  - `release-level-info`
@@ -196,7 +198,7 @@ pub mod prelude {
     pub use super::{Level, LevelFilter, Logger, LoggerBuilder};
 }
 
-use std::{result::Result as StdResult, sync::Arc};
+use std::{panic, result::Result as StdResult, sync::Arc};
 
 use arc_swap::ArcSwap;
 use cfg_if::cfg_if;
@@ -256,8 +258,9 @@ pub(crate) const EOL: &str = "\n";
 #[cfg(windows)]
 pub(crate) const EOL: &str = "\r\n";
 
-fn global_default_logger() -> &'static ArcSwap<Logger> {
-    static DEFAULT_LOGGER: OnceCell<ArcSwap<Logger>> = OnceCell::new();
+static DEFAULT_LOGGER: OnceCell<ArcSwap<Logger>> = OnceCell::new();
+
+fn default_logger_ref() -> &'static ArcSwap<Logger> {
     DEFAULT_LOGGER.get_or_init(|| {
         let stdout = StdStreamSink::new(StdStream::Stdout, StyleMode::Auto);
         stdout.set_level_filter(LevelFilter::MoreVerbose(Level::Warn));
@@ -267,7 +270,10 @@ fn global_default_logger() -> &'static ArcSwap<Logger> {
 
         let sinks: [Arc<dyn Sink>; 2] = [Arc::new(stdout), Arc::new(stderr)];
 
-        ArcSwap::from_pointee(Logger::builder().sinks(sinks).build_default())
+        let res = ArcSwap::from_pointee(Logger::builder().sinks(sinks).build_default());
+
+        flush_default_logger_at_exit();
+        res
     })
 }
 
@@ -296,7 +302,7 @@ fn global_default_logger() -> &'static ArcSwap<Logger> {
 /// critical!("this log will be written to `stderr`");
 /// ```
 pub fn default_logger() -> Arc<Logger> {
-    global_default_logger().load().clone()
+    default_logger_ref().load().clone()
 }
 
 /// Sets the given logger as the default logger, and returns the old default
@@ -315,7 +321,7 @@ pub fn default_logger() -> Arc<Logger> {
 /// info!(logger: old_logger, "this log will be handled by `old_logger`");
 /// ```
 pub fn swap_default_logger(logger: Arc<Logger>) -> Arc<Logger> {
-    global_default_logger().swap(logger)
+    default_logger_ref().swap(logger)
 }
 
 /// Sets the given logger as the default logger.
@@ -394,10 +400,10 @@ pub fn set_default_logger(logger: Arc<Logger>) {
 ///
 ///   ```
 ///   use spdlog::prelude::*;
-///  
+///
 ///   # fn main() -> Result<(), spdlog::EnvLevelError> {
 ///   assert_eq!(spdlog::init_env_level()?, false);
-///  
+///
 ///   assert_eq!(
 ///       spdlog::default_logger().level_filter(),
 ///       LevelFilter::MoreSevereEqual(Level::Info) // default level filter
@@ -421,11 +427,11 @@ pub fn set_default_logger(logger: Arc<Logger>) {
 ///
 ///   ```
 ///   use spdlog::prelude::*;
-///  
+///
 ///   # fn main() -> Result<(), spdlog::EnvLevelError> {
 ///   # std::env::set_var("SPDLOG_RS_LEVEL", "TRACE,network=Warn,*=error");
 ///   assert_eq!(spdlog::init_env_level()?, true);
-///  
+///
 ///   assert_eq!(
 ///       spdlog::default_logger().level_filter(),
 ///       LevelFilter::MoreSevereEqual(Level::Trace)
@@ -473,6 +479,11 @@ pub fn init_env_level() -> StdResult<bool, EnvLevelError> {
 /// Users should call this function only once. Get the proxy to configure by
 /// calling [`log_crate_proxy()`].
 ///
+/// Note that the `log` crate uses a different log level filter and by default
+/// it rejects all log messages. To log messages via the `log` crate, you have
+/// to call [`log::set_max_level`] manually before logging. For more
+/// information, please read the documentation of [`log::set_max_level`].
+///
 /// For more details, please read documentation of [`log::set_logger`] and
 /// [`LogCrateProxy`].
 #[cfg(feature = "log")]
@@ -489,6 +500,42 @@ pub fn log_crate_proxy() -> &'static LogCrateProxy {
     &PROXY
 }
 
+fn flush_default_logger_at_exit() {
+    // Rust never calls `drop` for static variables.
+    //
+    // Setting up an exit handler gives us a chance to flush the default logger
+    // once at the program exit, thus we don't lose the last logs.
+
+    extern "C" fn handler() {
+        if let Some(default_logger) = DEFAULT_LOGGER.get() {
+            default_logger.load().flush()
+        }
+    }
+
+    fn try_atexit() -> bool {
+        use std::os::raw::c_int;
+
+        extern "C" {
+            fn atexit(cb: extern "C" fn()) -> c_int;
+        }
+
+        (unsafe { atexit(handler) }) == 0
+    }
+
+    fn hook_panic() {
+        let previous_hook = panic::take_hook();
+
+        panic::set_hook(Box::new(move |info| {
+            handler();
+            previous_hook(info);
+        }));
+    }
+
+    if !try_atexit() {
+        hook_panic() // at least
+    }
+}
+
 fn default_error_handler(from: impl AsRef<str>, error: Error) {
     let date = chrono::Local::now()
         .format("%Y-%m-%d %H:%M:%S.%3f")
@@ -504,14 +551,19 @@ fn default_error_handler(from: impl AsRef<str>, error: Error) {
 
 // Used at log macros
 #[doc(hidden)]
-pub fn __log(logger: &Logger, level: Level, fmt_args: std::fmt::Arguments) {
+pub fn __log(
+    logger: &Logger,
+    level: Level,
+    srcloc: Option<SourceLocation>,
+    fmt_args: std::fmt::Arguments,
+) {
     // use `Cow` to avoid allocation as much as we can
     let payload: std::borrow::Cow<str> = match fmt_args.as_str() {
         Some(literal_str) => literal_str.into(), // no format arguments, so it is a `&'static str`
         None => fmt_args.to_string().into(),
     };
 
-    let mut builder = Record::builder(level, payload).source_location(source_location_current!());
+    let mut builder = Record::builder(level, payload).source_location(srcloc);
     if let Some(logger_name) = logger.name() {
         builder = builder.logger_name(logger_name);
     }
