@@ -12,7 +12,7 @@ pub struct PeriodicWorker {
 impl PeriodicWorker {
     // Panic if the `interval.is_zero()` is `true`.
     #[allow(clippy::mutex_atomic)]
-    pub fn new(callback: Box<dyn Fn() -> bool + Send + Sync>, interval: Duration) -> Self {
+    pub fn new(callback: impl Fn() -> bool + Send + Sync + 'static, interval: Duration) -> Self {
         if interval.is_zero() {
             panic!("PeriodicWorker: the interval cannot be zero")
         }
